<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAbout extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-about';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs About widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs About widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'about' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'About', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'background_bg',
			[
				'label'   => esc_html__( 'Featured Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
			
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'intro',
			[
				'label'       => __( 'Intro', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Intro', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'description',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Description', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->end_controls_section();

		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_intro',
			[
				'label'   => esc_html__( 'Show Intro', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_description',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings); ?>

		<div class="bg-light">
            <div class="container-fluid nopadding">
                <div class="extra-margin-all post-spacing">
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- divider start -->
                            <div class="inner-divider"></div>
                            <!-- divider end -->
                            <!-- line start -->
                            <div class="the-line"></div>
                            <!-- line end -->
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                            <!-- divider end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- section txt start -->
                            <div class="animated-text-wrapper">
                                <div class="animated-text">
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                </div>
                            </div>
                            <!-- section txt end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                            <!-- divider end -->
                            <!-- line start -->
                            <div class="the-line"></div>
                            <!-- line end -->
                            <!-- divider start -->
                            <div class="inner-divider"></div>
                            <!-- divider end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <!-- section start -->
        <div class="bg-light">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                        	<?php if ( '' !== $settings['subheading'] and $settings['show_subheading'] ) : ?>
                            <!-- section title start -->
                            <div class="subtitle subtitle-light"><?php print wp_kses_post($settings['subheading']); ?></div>
                            <!-- section title end -->
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                        	<?php endif; ?>
                            <!-- divider end -->
                            <div class="post-spacing-3">
                            	<?php if ( '' !== $settings['intro'] and $settings['show_intro'] ) : ?>
                                <!-- section txt start -->
                                <div class="intro">
                                    <?php print wp_kses_post($settings['intro']); ?>                            
                                </div>
                                <!-- section txt end -->
                                <!-- divider start -->
                                <div class="inner-divider-half"></div>
                                <!-- divider end -->
                                <?php endif; ?>
                                <?php if ( '' !== $settings['description'] and $settings['show_description'] ) : ?>
                                <!-- section txt start -->
                                <div class="section-txt">
                                    <p>
                                        <?php print wp_kses_post($settings['description']); ?>                                                                
                                    </p>
                                </div>
                                <!-- section txt end -->
                                <?php endif; ?>
                            </div>
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <!-- section start -->
        <div class="bg-light">
            <div class="container-fluid nopadding">
                <div class="extra-margin-all">
                    <div class="works-list">
                        <div class="works-list-content-wrapper works-list-content-wrapper-home">
                            <div class="works-list-wrapper works-list-wrapper-home">
                                <!-- section item start -->
                                <div class="works-list-item">
                                    <!-- section img start -->
                                    <div class="works-list-bg works-list-bg-home about-list-bg" style="background-image: url( <?php echo wp_kses_post($settings['background_bg']['url']); ?> );">
                                    </div>
                                    <!-- section img end -->
                                </div>
                                <!-- section item end -->
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
	<?php
	}

}