<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBlog extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-blog';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Blog widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Blog widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'Blog' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Blog', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'intro',
			[
				'label'       => __( 'Intro', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Intro', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'description',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Description', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),
				'default'   => '4',
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_order',
			[
				'label'     => esc_html__( 'Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'asc',
			]
		);

		$this->end_controls_section();
		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_intro',
			[
				'label'   => esc_html__( 'Show Intro', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_description',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_all',
			[
				'label'   => esc_html__( 'Show Subheading + Intro + Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display(); 
		extract($settings);	
		$post_number = $settings['post_number'];
	    $order = $settings['post_order'];
	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => $order));
	   
	    //other style
	    $args = array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => $order);	
	   	?>
		<div class="bg-light">
            <div class="container-fluid nopadding">
                <div class="extra-margin-all post-spacing">
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- divider start -->
                            <div class="inner-divider"></div>
                            <!-- divider end -->
                            <!-- line start -->
                            <div class="the-line"></div>
                            <!-- line end -->
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                            <!-- divider end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- section txt start -->
                            <div class="animated-text-wrapper">
                                <div class="animated-text">
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                </div>
                            </div>
                            <!-- section txt end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                            <!-- divider end -->
                            <!-- line start -->
                            <div class="the-line"></div>
                            <!-- line end -->
                            <!-- divider start -->
                            <div class="inner-divider"></div>
                            <!-- divider end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <!-- section start -->
        <?php if ( $settings['show_all'] ) : ?>
        <!-- section end -->
        <div class="bg-light">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <?php if ( '' !== $settings['subheading'] and $settings['show_subheading'] ) : ?>
                            <!-- section title start -->
                            <div class="subtitle subtitle-light"><?php print wp_kses_post($settings['subheading']); ?></div>
                            <!-- section title end -->
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                        	<?php endif; ?>
                            <!-- divider end -->
                            <div class="post-spacing-3">
                            	<?php if ( '' !== $settings['intro'] and $settings['show_intro'] ) : ?>
                                <!-- section txt start -->
                                <div class="intro">
                                    <?php print wp_kses_post($settings['intro']); ?>                            
                                </div>
                                <!-- section txt end -->
                                <!-- divider start -->
                                <div class="inner-divider-half"></div>
                                <!-- divider end -->
                                <?php endif; ?>
                                <?php if ( '' !== $settings['description'] and $settings['show_description'] ) : ?>
                                <!-- section txt start -->
                                <div class="section-txt">
                                    <p>
                                        <?php print wp_kses_post($settings['description']); ?>                                                                
                                    </p>
                                </div>
                                <!-- section txt end -->
                                <?php endif; ?>
                            </div>
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                </div>
            </div>
        </div>
    	<?php endif; ?>
        <!-- section end -->
        <?php $i=0;
            $args = new \WP_Query(array(   
                        'post_type' => 'post', 
                    ));  
            while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
            $i++;
        ?>
        <?php if($i % 4 == 1){ ?>
        <!-- section start -->
        <div class="bg-light">
            <div class="container-fluid nopadding">
                <div class="extra-margin-all">
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- showcase start -->
                            <div class="showcase">
                                <div class="showcase-img-left">
                                    <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Img">
                                    <!-- section txt start -->
                                    <div class="showcase-txt-wrapper">
                                        <!-- section title start -->
                                        <div class="showcase-name">
                                            <?php the_title(); ?>                                       
                                        </div>
                                        <!-- section title end -->
                                        <!-- section title start -->
                                        <span class="subtitle-blog"><?php the_time(get_option('date_format')); ?></span>
                                        <!-- section title end -->
                                        <!-- divider start -->
                                        <div class="inner-divider-50"></div>
                                        <!-- divider end -->
                                        <!-- section txt start -->
                                        <div class="section-txt">
                                            <p>
                                                <?php if(isset($bravex_redux_demo['blog_excerpt'])){?>
								                <?php echo esc_attr(bravex_excerpt($bravex_redux_demo['blog_excerpt'])); ?>
								                <?php }else{?>
								                <?php echo esc_attr(bravex_excerpt(40)); 
								                ?> 
								            	<?php } ?>                                            
                                            </p>
                                        </div>
                                        <!-- section txt end -->
                                        <!-- divider start -->
                                        <div class="inner-divider-50"></div>
                                        <!-- divider end -->
                                        <!-- button start -->
                                        <a href="<?php the_permalink(); ?>">
                                            <div class="button-the-wrapper button-the-wrapper-dark">
                                                <span class="button-the">
	                                                <?php if(isset($bravex_redux_demo['read_more'])){?>
						                            <?php echo wp_specialchars_decode(esc_attr($bravex_redux_demo['read_more']));?>
						                            <?php }else{?>
						                            <?php echo esc_html__( 'Read More', 'bravex' );?>
						                        	<?php } ?>
	                                            </span>
                                            </div>
                                        </a>
                                        <!-- button end -->
                                    </div>
                                    <!-- section txt end -->
                                    <!-- divider start -->
                                    <div class="inner-divider-half"></div>
                                    <!-- divider end -->
                                </div>
                                <?php }elseif($i % 4 == 2){ ?>
                                <div class="showcase-img-right">
                                    <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Img">
                                    <!-- section txt start -->
                                    <div class="showcase-txt-wrapper">
                                        <!-- section title start -->
                                        <div class="showcase-name">
                                            <?php the_title(); ?>                                       
                                        </div>
                                        <!-- section title end -->
                                        <!-- section title start -->
                                        <span class="subtitle-blog"><?php the_time(get_option('date_format')); ?></span>
                                        <!-- section title end -->
                                        <!-- divider start -->
                                        <div class="inner-divider-50"></div>
                                        <!-- divider end -->
                                        <!-- section txt start -->
                                        <div class="section-txt">
                                            <p>
                                                <?php if(isset($bravex_redux_demo['blog_excerpt'])){?>
								                <?php echo esc_attr(bravex_excerpt($bravex_redux_demo['blog_excerpt'])); ?>
								                <?php }else{?>
								                <?php echo esc_attr(bravex_excerpt(40)); 
								                ?> 
								            	<?php } ?>                                            
                                            </p>
                                        </div>
                                        <!-- section txt end -->
                                        <!-- divider start -->
                                        <div class="inner-divider-50"></div>
                                        <!-- divider end -->
                                        <!-- button start -->
                                        <a href="<?php the_permalink(); ?>">
                                            <div class="button-the-wrapper button-the-wrapper-dark">
                                                <span class="button-the">
	                                                <?php if(isset($bravex_redux_demo['read_more'])){?>
						                            <?php echo wp_specialchars_decode(esc_attr($bravex_redux_demo['read_more']));?>
						                            <?php }else{?>
						                            <?php echo esc_html__( 'Read More', 'bravex' );?>
						                        	<?php } ?>
	                                            </span>
                                            </div>
                                        </a>
                                        <!-- button end -->
                                    </div>
                                    <!-- divider start -->
                                    <div class="inner-divider-half"></div>
                                    <!-- divider end -->
                                </div>
                            </div>
                            <!-- showcase end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
        <!-- section end -->
    	<?php }elseif($i % 4 == 3){ ?>
        <!-- section start -->
        <div class="bg-light">
            <div class="container-fluid nopadding">
                <div class="extra-margin-all">
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- showcase start -->
                            <div class="showcase">
                                <div class="showcase-img-left">
                                    <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Img">
                                    <!-- section txt start -->
                                    <div class="showcase-txt-wrapper">
                                        <!-- section title start -->
                                        <div class="showcase-name">
                                            <?php the_title(); ?>                                       
                                        </div>
                                        <!-- section title end -->
                                        <!-- section title start -->
                                        <span class="subtitle-blog"><?php the_time(get_option('date_format')); ?></span>
                                        <!-- section title end -->
                                        <!-- divider start -->
                                        <div class="inner-divider-50"></div>
                                        <!-- divider end -->
                                        <!-- section txt start -->
                                        <div class="section-txt">
                                            <p>
                                                <?php if(isset($bravex_redux_demo['blog_excerpt'])){?>
								                <?php echo esc_attr(bravex_excerpt($bravex_redux_demo['blog_excerpt'])); ?>
								                <?php }else{?>
								                <?php echo esc_attr(bravex_excerpt(40)); 
								                ?> 
								            	<?php } ?>                                            
                                            </p>
                                        </div>
                                        <!-- section txt end -->
                                        <!-- divider start -->
                                        <div class="inner-divider-50"></div>
                                        <!-- divider end -->
                                        <!-- button start -->
                                        <a href="<?php the_permalink(); ?>">
                                            <div class="button-the-wrapper button-the-wrapper-dark">
                                                <span class="button-the">
	                                                <?php if(isset($bravex_redux_demo['read_more'])){?>
						                            <?php echo wp_specialchars_decode(esc_attr($bravex_redux_demo['read_more']));?>
						                            <?php }else{?>
						                            <?php echo esc_html__( 'Read More', 'bravex' );?>
						                        	<?php } ?>
	                                            </span>
                                            </div>
                                        </a>
                                        <!-- button end -->
                                    </div>
                                    <!-- divider start -->
                                    <div class="inner-divider-half mobile-visible"></div>
                                    <!-- divider end -->
                                </div>
                            	<?php }else{ ?>
                                <div class="showcase-img-right">
                                    <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Img">
                                    <!-- section txt start -->
                                    <div class="showcase-txt-wrapper">
                                        <!-- section title start -->
                                        <div class="showcase-name">
                                            <?php the_title(); ?>                                       
                                        </div>
                                        <!-- section title end -->
                                        <!-- section title start -->
                                        <span class="subtitle-blog"><?php the_time(get_option('date_format')); ?></span>
                                        <!-- section title end -->
                                        <!-- divider start -->
                                        <div class="inner-divider-50"></div>
                                        <!-- divider end -->
                                        <!-- section txt start -->
                                        <div class="section-txt">
                                            <p>
                                                <?php if(isset($bravex_redux_demo['blog_excerpt'])){?>
								                <?php echo esc_attr(bravex_excerpt($bravex_redux_demo['blog_excerpt'])); ?>
								                <?php }else{?>
								                <?php echo esc_attr(bravex_excerpt(40)); 
								                ?> 
								            	<?php } ?>                                            
                                            </p>
                                        </div>
                                        <!-- section txt end -->
                                        <!-- divider start -->
                                        <div class="inner-divider-50"></div>
                                        <!-- divider end -->
                                        <!-- button start -->
                                        <a href="<?php the_permalink(); ?>">
                                            <div class="button-the-wrapper button-the-wrapper-dark">
                                                <span class="button-the">
	                                                <?php if(isset($bravex_redux_demo['read_more'])){?>
						                            <?php echo wp_specialchars_decode(esc_attr($bravex_redux_demo['read_more']));?>
						                            <?php }else{?>
						                            <?php echo esc_html__( 'Read More', 'bravex' );?>
						                        	<?php } ?>
	                                            </span>
                                            </div>
                                        </a>
                                        <!-- button end -->
                                    </div>
                                </div>
                            </div>
                            <!-- showcase end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
    	<?php } ?>
    	<?php endwhile; ?>
        <!-- section end -->
	<?php
	}

}