<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsContact extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-contact';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Contact', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Contact widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-headphones';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Contact widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'contact', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Contact', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'intro',
			[
				'label'       => __( 'Intro', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Intro', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'video',
			[
				'label'       => __( 'Link Video', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('#', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Button', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	
		
		$this->add_control(
			'shortcode',
			[
				'label'   => esc_html__( 'Contact Form', 'bdevs-elementor' ),
				'type'    => Controls_Manager::TEXTAREA,
				'dynamic' => [ 'active' => true ],
				'default'		=> __('Contact Form', 'bdevs-elementor'),
				'description' => esc_html__( 'Add your contact form here', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_contact',
			[
				'label' => esc_html__( 'Contact Info', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'        => 'title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'contact_info',
						'label'       => esc_html__( 'Contact Info', 'bdevs-elementor' ),
						'type'        => Controls_Manager::WYSIWYG,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Contact Info' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_intro',
			[
				'label'   => esc_html__( 'Show Intro', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_video',
			[
				'label'   => esc_html__( 'Show Video', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_form',
			[
				'label'   => esc_html__( 'Show Form', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>
		<div class="bg-light">
            <div class="container-fluid nopadding">
                <div class="extra-margin-all post-spacing">
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- divider start -->
                            <div class="inner-divider"></div>
                            <!-- divider end -->
                            <!-- line start -->
                            <div class="the-line"></div>
                            <!-- line end -->
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                            <!-- divider end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- section txt start -->
                            <div class="animated-text-wrapper">
                                <div class="animated-text">
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                    <div class="animated-text-content"><?php print wp_kses_post($settings['heading']); ?>&nbsp;</div>
                                </div>
                            </div>
                            <!-- section txt end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                            <!-- divider end -->
                            <!-- line start -->
                            <div class="the-line"></div>
                            <!-- line end -->
                            <!-- divider start -->
                            <div class="inner-divider"></div>
                            <!-- divider end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <!-- section start -->
        <div class="bg-light">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                        	<?php if ( '' !== $settings['subheading'] and $settings['show_subheading'] ) : ?>
                            <!-- section title start -->
                            <div class="subtitle subtitle-light"><?php print wp_kses_post($settings['subheading']); ?></div>
                            <!-- section title end -->
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                        	<?php endif; ?>
                            <!-- divider end -->
                            <?php if ( '' !== $settings['intro'] and $settings['show_intro'] ) : ?>
                            <div class="post-spacing-3">
                                <!-- section txt start -->
                                <div class="intro">
                                    <?php print wp_kses_post($settings['intro']); ?>                            
                                </div>
                                <!-- section txt end -->
                                
                            </div>
                            <?php endif; ?>
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <?php if ( '' !== $settings['video'] and $settings['show_video'] ) : ?>
        <!-- section start -->
        <div class="bg-light">
            <div class="container-fluid nopadding">
                <div class="extra-margin-all post-spacing">
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- button start -->
                            <div class="more-wraper-center">
                                <a class="button" data-lity="" href="<?php print wp_kses_post($settings['video']); ?>">
                                    <i class="pulse"></i>
                                    <div class="more-button-bg-center more-button-circle"></div>
                                    <div class="more-button-txt-center">
                                        <span><?php print wp_kses_post($settings['button']); ?></span>
                                    </div>
                                </a>
                            </div>
                            <!-- button end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                </div>
            </div>
        </div>
        <!-- section end -->
    	<?php endif; ?>
    	<?php if ( $settings['show_form'] ) : ?>
    	<div class="bg-light">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- row start -->
                    <div class="row">
                        <div class="post-spacing-3">
                            <!-- col start -->
                            <div>
                                <!-- contact form start -->
                                <div id="contact-form">
                                    <?php print do_shortcode(html_entity_decode( $settings['shortcode'] )); ?>
                                </div>
                                <!-- contact form end -->
                            </div>
                            <!-- col end -->
                        </div>
                    </div>
                    <!-- row end -->
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                </div>
            </div>
        </div>
        <?php endif; ?>
        <!-- section start -->
        <div class="bg-dark">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                    <!-- row start -->
                    <div class="row">
                        <div class="post-spacing-3">
                        	<?php $i=0;
			                    foreach ( $settings['tabs'] as $item ) : 
			                    $i++;
							?>
                            <!-- col start -->
                            <div class="col-md-4 col-sm-12">
                                <!-- section title start -->
                                <div class="subtitle subtitle-light subtitle-light-2"><?php print wp_kses_post($item['title']); ?></div>
                                <!-- section title end -->
                                <!-- divider start -->
                                <div class="inner-divider-50"></div>
                                <!-- divider end -->
                                <!-- section TXT start -->
                                <div class="section-txt-2">
                                    <p><?php print wp_kses_post($item['contact_info']); ?></p>
                                </div>
                                <!-- section TXT end -->
                                <!-- divider start -->
                                <div class="inner-divider-half mobile-visible"></div>
                                <!-- divider end -->
                            </div>
                            <!-- col end -->
                        	<?php endforeach; ?>
                        </div>
                    </div>
                    <!-- row end -->
                    <!-- divider start -->
                    <div class="inner-divider inner-divider-last"></div>
                    <!-- divider end -->
                </div>
            </div>
        </div>
	<?php
	}

}