<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsFeatures extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-Features';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Features', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Features widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Features widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'Features' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Features', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'intro',
			[
				'label'       => __( 'Intro', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Intro', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_team',
			[
				'label' => esc_html__( 'Features Items', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'        => 'title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'content',
						'label'       => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Content' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();

		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_intro',
			[
				'label'   => esc_html__( 'Show Intro', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings); ?>
		<div class="bg-dark">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                        	<?php if ( '' !== $settings['subheading'] and $settings['show_subheading'] ) : ?>
                            <!-- section title start -->
                            <div class="subtitle subtitle-light"><?php print wp_kses_post($settings['subheading']); ?></div>
                            <!-- section title end -->
                            <!-- divider start -->
                            <div class="inner-divider-half"></div>
                        	<?php endif; ?>
                            <!-- divider end -->
                            <?php if ( '' !== $settings['intro'] and $settings['show_intro'] ) : ?>
                            <div class="post-spacing-3">
                                <!-- section txt start -->
                                <div class="intro">
                                    <?php print wp_kses_post($settings['intro']); ?>                            
                                </div>
                                <!-- section txt end -->
                                
                            </div>
                            <?php endif; ?>
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <!-- section start -->
        <div class="bg-light">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <!-- panel wrapper start -->
                            <div class="panel-wrapper">
                                <div class="panel-group" id="accordion" role="tablist" aria-multiselectable="true">
                                	<?php $i=0;
					                    foreach ( $settings['tabs'] as $item ) : 
					                    $i++;
									?>
									<?php if($i == 1){ ?>
                                    <div class="panel panel-default">
                                        <div class="panel-heading" id="heading<?php echo $i; ?>" role="tab">
                                            <h4 class="panel-title">
                                                <a role="button" data-toggle="collapse" data-parent="#accordion" href="#collapse<?php echo $i; ?>" aria-expanded="true" aria-controls="collapse<?php echo $i; ?>">
                                                    <!-- section title start -->
                                                    <span class="panel-title">
                                                    <?php print wp_kses_post($item['title']); ?>                                                   
                                                    </span>
                                                    <!-- section title end -->
                                                    <i class="pull-left ion ion-plus"></i>   
                                                </a>
                                            </h4>
                                        </div>
                                        <div class="panel-collapse collapse in" id="collapse<?php echo $i; ?>" role="tabpanel" aria-labelledby="heading<?php echo $i; ?>">
                                            <!-- section txt start -->
                                            <div class="panel-body">
                                                <p><?php print wp_kses_post($item['content']); ?></p>
                                            </div>
                                            <!-- section txt end -->
                                        </div>
                                    </div>
                                	<?php }else{ ?>
                                	<div class="panel panel-default">
                                        <div class="panel-heading" id="heading<?php echo $i; ?>" role="tab">
                                            <h4 class="panel-title">
                                                <a class="collapsed" role="button" data-toggle="collapse" data-parent="#accordion" href="#collapse<?php echo $i; ?>" aria-expanded="false" aria-controls="collapse<?php echo $i; ?>">
                                                    <!-- section title start -->
                                                    <span class="panel-title">
                                                    <?php print wp_kses_post($item['title']); ?>                                                
                                                    </span>
                                                    <!-- section title end -->
                                                    <i class="pull-left ion ion-plus"></i>
                                                </a>
                                            </h4>
                                        </div>
                                        <div class="panel-collapse collapse" id="collapse<?php echo $i; ?>" role="tabpanel" aria-labelledby="heading<?php echo $i; ?>">
                                            <!-- section txt start -->
                                            <div class="panel-body">
                                                <p><?php print wp_kses_post($item['content']); ?></p>
                                            </div>
                                            <!-- section txt end -->
                                        </div>
                                    </div>
                                	<?php } ?>
                                	<?php endforeach; ?>
                                </div>
                            </div>
                            <!-- panel wrapper end -->
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
	<?php
	}

}