<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsSlider01 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-slider-one';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Multi Slider', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-album';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'slider', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Slider', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Select Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'slider_style_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
					'slider_style_2' => esc_html__( 'Style 2', 'bdevs-elementor' ),
					'slider_style_3' => esc_html__( 'Style 3', 'bdevs-elementor' ),
				],
				'default'   => 'slider_style_1',
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Description', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'author',
			[
				'label'       => __( 'Author', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Author', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout11',
			[
				'label' => esc_html__( 'Slider Items', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'        => 'chose_style',
						'label'       => esc_html__( 'Select Style', 'bdevs-elementor' ),
						'type'        => Controls_Manager::SELECT,
						'dynamic'     => [ 'active' => true ],
						'options'   => [
								'image' => esc_html__( 'Image', 'bdevs-elementor' ),
								'video'  => esc_html__( 'Video', 'bdevs-elementor' ),
							],
							'default'   => 'image',
						'label_block' => true,
					],
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'condition' => [
		                    'chose_style' => ['image']
		                ],
					],
					[
						'name'        => 'video',
						'label'       => esc_html__( 'Link Video (mp4)', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
						'condition' => [
		                    'chose_style' => ['video']
		                ],
					],
					[
						'name'        => 'button',
						'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Button' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'link',
						'label'       => esc_html__( 'Link Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_description',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>
		<?php if( $chose_style == 'slider_style_1' ): ?>
		<div>
            <div class="main-title-wrapper-img hero-bg overlay overlay-dark">
                <!-- hero slider wrapper start -->
                <div class="swiper-container-wrapper">
                    <!-- swiper container start -->
                    <div class="swiper-container swiper1">
                        <!-- swiper wrapper start -->
                        <div class="swiper-wrapper">
                        	<?php 
			                    foreach ( $settings['tabs'] as $item ) : 
							?>
                            <!-- swiper slider item start -->
                            <div class="swiper-slide">
                                <div class="swiper-slide-inner" data-swiper-parallax="50%">
                                	<?php if( wp_kses_post($item['chose_style']) == 'image'): ?> 
                                    <!-- swiper slider item IMG start -->
                                    <div class="swiper-slide-inner-bg bg-img-1 overlay overlay-dark" style="background-image: url(<?php echo wp_kses_post($item['tab_image']['url']); ?> );">                                    </div>
                                    <!-- swiper slider item IMG end -->
                                    <?php elseif( wp_kses_post($item['chose_style']) == 'video'): ?>
                                    <div class="swiper-slide-inner-bg overlay overlay-dark">
                                        <!-- HTML5 video URL start -->
                                        <video playsinline autoplay muted loop>
                                            <source src="<?php print wp_kses_post($item['video']); ?>" type="video/mp4">
                                        </video>
                                        <!-- HTML5 video URL end -->
                                    </div>
                                    <?php endif; ?>
                                    <!-- swiper slider item txt start -->
                                    <div class="swiper-slide-inner-txt">
                                        <!-- button start -->
                                        <div class="more-wraper-center">
                                            <a class="button button-effect button-effect-light" href="<?php print wp_kses_post($item['link']); ?>">
                                            	<div class="more-button-bg-center more-button-circle"></div>
			                                    <div class="more-button-txt-center more-button-txt-center-light">
			                                        <span><?php print wp_kses_post($item['button']); ?></span>
			                                    </div>
                                            </a>
                                        </div>
                                        <!-- button end -->
                                    </div>
                                    <!-- swiper slider item txt end -->
                                </div>
                            </div>
                            <!-- swiper slider item end -->
                        	<?php endforeach; ?>
                        </div>
                        <!-- swiper wrapper end -->   
                    </div>
                    <!-- swiper container end -->
                </div>
                <!-- hero slider wrapper end -->
                <!-- swiper slider controls start -->
                <div>
                    <div class="swiper-slide-controls slide-prev">
                        <span>
                            <svg class="circle-svg" height="50" width="50">
                                <circle class="circle" cx="25" cy="25" r="24"></circle>
                            </svg>
                        </span>
                        <div class="ion-ios-arrow-left"></div>
                    </div>
                    <div class="swiper-slide-controls slide-next">
                        <span>
                            <svg class="circle-svg" height="50" width="50">
                                <circle class="circle" cx="25" cy="25" r="24"></circle>
                            </svg>
                        </span>
                        <div class="ion-ios-arrow-right"></div>
                    </div>
                </div>
                <!-- swiper slider controls end -->
                <div data-scroll class="main-title-wrapper-img-hero">
                </div>
                <?php if ( '' !== $settings['subheading'] and $settings['show_subheading'] ) : ?>
                <div class="main-title-wrapper-s">
                    <!-- section title start -->
                    <h2 class="main-title-main-color-s">
                        <?php print wp_kses_post($settings['subheading']); ?>       
                    </h2>
                    <!-- section title end -->
                </div>
            	<?php endif; ?>
            </div>
        </div>
        <?php if ( '' !== $settings['subheading'] and $settings['show_heading'] ) : ?>
        <div class="main-title-wrapper-l">
            <!-- section title start -->
            <h1 class="main-title-main-color-l">
                <?php print wp_kses_post($settings['heading']); ?>
            </h1>
            <!-- section title end -->
        </div>
        <!-- home end -->
        <?php endif; ?>
        <!-- home end -->
        <!-- vertical lines start -->
        <div class="vertical-lines-wrapper">
            <div class="vertical-lines"></div>
        </div>
        <!-- vertical lines end -->
        <!-- works start -->
        <?php if ( '' !== $settings['description'] and $settings['show_description'] ) : ?>
        <!-- section start -->
        <div class="bg-light">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <div class="post-spacing-3">
                                <!-- section txt start -->
                                <div class="intro">
                                    <?php print wp_kses_post($settings['description']); ?>                           
                                </div>
                                <!-- section txt end -->
                                <!-- divider start -->
                                <div class="inner-divider-half"></div>
                                <!-- divider end -->
                                <!-- section txt start -->
                                <div class="testimonials-signature">
                                    <?php print wp_kses_post($settings['author']); ?>
                                </div>
                                <!-- section txt end -->
                            </div>
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <?php endif; ?>
        <?php elseif( $chose_style == 'slider_style_2' ): ?>
        <div>
            <div class="main-title-wrapper-img hero-bg overlay overlay-dark">
                <!-- hero slider wrapper start -->
                <div class="swiper-container-wrapper">
                    <!-- swiper container start -->
                    <div class="swiper-container swiper2">
                        <!-- swiper wrapper start -->
                        <div class="swiper-wrapper">
                        	<?php 
			                    foreach ( $settings['tabs'] as $item ) : 
							?>
                            <!-- swiper slider item start -->
                            <div class="swiper-slide">
                                <div class="swiper-slide-inner">
                                    <!-- swiper slider item IMG start -->
                                    <div class="swiper-slide-inner-bg bg-img-1 overlay overlay-dark" style="background-image: url(<?php echo wp_kses_post($item['tab_image']['url']); ?> );"></div>
                                    <!-- swiper slider item IMG end -->
                                    <!-- swiper slider item txt start -->
                                    <div class="swiper-slide-inner-txt">
                                        <!-- button start -->
                                        <div class="more-wraper-center">
                                            <a class="button button-effect button-effect-light" href="<?php print wp_kses_post($item['link']); ?>">
                                            	<div class="more-button-bg-center more-button-circle"></div>
			                                    <div class="more-button-txt-center more-button-txt-center-light">
			                                        <span><?php print wp_kses_post($item['button']); ?></span>
			                                    </div>
                                            </a>
                                        </div>
                                        <!-- button end -->
                                    </div>
                                    <!-- swiper slider item txt end -->
                                </div>
                            </div>
                            <!-- swiper slider item end -->
                        	<?php endforeach; ?>
                        </div>
                        <!-- swiper wrapper end -->   
                    </div>
                    <!-- swiper container end -->
                </div>
                <!-- hero slider wrapper end -->
                <!-- swiper slider controls start -->
                <div>
                    <div class="swiper-slide-controls slide-prev">
                        <span>
                            <svg class="circle-svg" height="50" width="50">
                                <circle class="circle" cx="25" cy="25" r="24"></circle>
                            </svg>
                        </span>
                        <div class="ion-ios-arrow-left"></div>
                    </div>
                    <div class="swiper-slide-controls slide-next">
                        <span>
                            <svg class="circle-svg" height="50" width="50">
                                <circle class="circle" cx="25" cy="25" r="24"></circle>
                            </svg>
                        </span>
                        <div class="ion-ios-arrow-right"></div>
                    </div>
                </div>
                <!-- swiper slider controls end -->
                <div data-scroll class="main-title-wrapper-img-hero">
                </div>
                <?php if ( '' !== $settings['subheading'] and $settings['show_subheading'] ) : ?>
                <div class="main-title-wrapper-s">
                    <!-- section title start -->
                    <h2 class="main-title-main-color-s">
                        <?php print wp_kses_post($settings['subheading']); ?>       
                    </h2>
                    <!-- section title end -->
                </div>
            	<?php endif; ?>
            </div>
        </div>
        <?php if ( '' !== $settings['subheading'] and $settings['show_heading'] ) : ?>
        <div class="main-title-wrapper-l">
            <!-- section title start -->
            <h1 class="main-title-main-color-l">
                <?php print wp_kses_post($settings['heading']); ?>
            </h1>
            <!-- section title end -->
        </div>
        <!-- home end -->
        <?php endif; ?>
        <!-- home end -->
        <!-- vertical lines start -->
        <div class="vertical-lines-wrapper">
            <div class="vertical-lines"></div>
        </div>
        <!-- vertical lines end -->
        <!-- works start -->
        <?php if ( '' !== $settings['description'] and $settings['show_description'] ) : ?>
        <!-- section start -->
        <div class="bg-light">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <div class="post-spacing-3">
                                <!-- section txt start -->
                                <div class="intro">
                                    <?php print wp_kses_post($settings['description']); ?>                           
                                </div>
                                <!-- section txt end -->
                                <!-- divider start -->
                                <div class="inner-divider-half"></div>
                                <!-- divider end -->
                                <!-- section txt start -->
                                <div class="testimonials-signature">
                                    <?php print wp_kses_post($settings['author']); ?>
                                </div>
                                <!-- section txt end -->
                            </div>
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <?php endif; ?>
        <?php if (is_admin())
		  { ?>
		<script type="text/javascript">
			var swiper2 = new Swiper(".swiper-container-wrapper .swiper-container.swiper2", {
		        preloadImages: false,
		        autoplay: {
		            delay: 4000,
		            disableOnInteraction: false
		        },
		        init: true,
		        loop: true,
		        speed: 1200,
		        grabCursor: true,
		        mousewheel: false,
		        keyboard: true,
		        simulateTouch: true,
		        parallax: true,
		        effect: "slide",
		        pagination: {
		            el: ".swiper-slide-pagination",
		            clickable: true
		        },
		        navigation: {
		            nextEl: ".slide-next",
		            prevEl: ".slide-prev"
		        },
				centeredSlides: true,
		        slidesPerView: 2,
		        spaceBetween: 0,
		        breakpoints: {
		            320: {
		                slidesPerView: 2,
		                spaceBetween: 0
		            },
		            480: {
		                slidesPerView: 2,
		                spaceBetween: 0
		            },
		            640: {
		                slidesPerView: 2,
		                spaceBetween: 0
		            }
		        }
		    });
		</script>
		<?php }  ?>
        <?php elseif( $chose_style == 'slider_style_3' ): ?>
        <div>
            <div class="main-title-wrapper-img hero-bg overlay overlay-dark">
                <!-- hero slider wrapper start -->
                <div class="swiper-container-wrapper">
                    <!-- swiper container start -->
                    <div class="swiper-container swiper3">
                        <!-- swiper wrapper start -->
                        <div class="swiper-wrapper">
                        	<?php 
			                    foreach ( $settings['tabs'] as $item ) : 
							?>
                            <!-- swiper slider item start -->
                            <div class="swiper-slide swiper-slide-3">
                                <div class="swiper-slide-inner">
                                    <!-- swiper slider item IMG start -->
                                    <div class="swiper-slide-inner-bg bg-img-1 overlay overlay-dark" style="background-image: url(<?php echo wp_kses_post($item['tab_image']['url']); ?> );">                                    </div>
                                    <!-- swiper slider item IMG end -->
                                </div>
                            </div>
                            <!-- swiper slider item end -->
                        	<?php endforeach; ?>
                        </div>
                        <!-- swiper wrapper end -->   
                    </div>
                    <!-- swiper container end -->
                </div>
                <!-- hero slider wrapper end -->
                <!-- swiper slider controls start -->
                <div>
                    <div class="swiper-slide-controls slide-prev">
                        <span>
                            <svg class="circle-svg" height="50" width="50">
                                <circle class="circle" cx="25" cy="25" r="24"></circle>
                            </svg>
                        </span>
                        <div class="ion-ios-arrow-left"></div>
                    </div>
                    <div class="swiper-slide-controls slide-next">
                        <span>
                            <svg class="circle-svg" height="50" width="50">
                                <circle class="circle" cx="25" cy="25" r="24"></circle>
                            </svg>
                        </span>
                        <div class="ion-ios-arrow-right"></div>
                    </div>
                </div>
                <!-- swiper slider controls end -->
                <div data-scroll class="main-title-wrapper-img-hero">
                </div>
                <?php if ( '' !== $settings['subheading'] and $settings['show_subheading'] ) : ?>
                <div class="main-title-wrapper-s">
                    <!-- section title start -->
                    <h2 class="main-title-main-color-s">
                        <?php print wp_kses_post($settings['subheading']); ?>       
                    </h2>
                    <!-- section title end -->
                </div>
            	<?php endif; ?>
            </div>
        </div>
        <?php if ( '' !== $settings['subheading'] and $settings['show_heading'] ) : ?>
        <div class="main-title-wrapper-l">
            <!-- section title start -->
            <h1 class="main-title-main-color-l">
                <?php print wp_kses_post($settings['heading']); ?>
            </h1>
            <!-- section title end -->
        </div>
        <!-- home end -->
        <?php endif; ?>
        <!-- home end -->
        <!-- vertical lines start -->
        <div class="vertical-lines-wrapper">
            <div class="vertical-lines"></div>
        </div>
        <!-- vertical lines end -->
        <!-- works start -->
        <?php if ( '' !== $settings['description'] and $settings['show_description'] ) : ?>
        <!-- section start -->
        <div class="bg-light">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <div class="post-spacing-3">
                                <!-- section txt start -->
                                <div class="intro">
                                    <?php print wp_kses_post($settings['description']); ?>                           
                                </div>
                                <!-- section txt end -->
                                <!-- divider start -->
                                <div class="inner-divider-half"></div>
                                <!-- divider end -->
                                <!-- section txt start -->
                                <div class="testimonials-signature">
                                    <?php print wp_kses_post($settings['author']); ?>
                                </div>
                                <!-- section txt end -->
                            </div>
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <?php endif; ?>
        <?php endif; ?>
	<?php
	}

}