<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsSlider02 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-slider-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Single Slider', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slides';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'slider', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Slider', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Select Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'image'  => esc_html__( 'Image', 'bdevs-elementor' ),
					'video' => esc_html__( 'Video', 'bdevs-elementor' ),
				],
				'default'   => 'image',
			]
		);

		$this->add_control(
			'background_bg',
			[
				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
				'condition' => [
                    'chose_style' => ['image']
                ],
			]
		);

		$this->add_control(
			'video',
			[
				'label'       => __( 'Link Video(mp4)', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('#', 'bdevs-elementor'),
				'label_block' => true,
				'condition' => [
                    'chose_style' => ['video']
                ],
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Description', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'author',
			[
				'label'       => __( 'Author', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Author', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_description',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>
		<?php if( $chose_style == 'image' ): ?>
		<div>
            <div class="main-title-wrapper-img hero-bg bg-img-1 overlay overlay-dark" style="background-image: url(<?php echo wp_kses_post($settings['background_bg']['url']); ?> );">
                <div data-scroll class="main-title-wrapper-img-hero">
                </div>
                <?php if ( '' !== $settings['subheading'] and $settings['show_subheading'] ) : ?>
                <div class="main-title-wrapper-s">
                    <!-- section title start -->
                    <h2 class="main-title-main-color-s">
                        <?php print wp_kses_post($settings['subheading']); ?>       
                    </h2>
                    <!-- section title end -->
                </div>
            	<?php endif; ?>
            </div>
        </div>
        <?php elseif( $chose_style == 'video' ): ?>
        <div>
            <div class="main-title-wrapper-img hero-bg overlay overlay-dark">
                <!-- HTML5 video URL start -->
                <video playsinline autoplay muted loop>
                    <source src="<?php print wp_kses_post($settings['video']); ?>" type="video/mp4">
                </video>
                <!-- HTML5 video URL end -->
                <div data-scroll class="main-title-wrapper-img-hero">
                </div>
                <?php if ( '' !== $settings['subheading'] and $settings['show_subheading'] ) : ?>
                <div class="main-title-wrapper-s">
                    <!-- section title start -->
                    <h2 class="main-title-main-color-s">
                        <?php print wp_kses_post($settings['subheading']); ?>       
                    </h2>
                    <!-- section title end -->
                </div>
            	<?php endif; ?>
            </div>
        </div>
        <?php endif; ?>
        <?php if ( '' !== $settings['subheading'] and $settings['show_heading'] ) : ?>
        <div class="main-title-wrapper-l">
            <!-- section title start -->
            <h1 class="main-title-main-color-l">
                <?php print wp_kses_post($settings['heading']); ?>
            </h1>
            <!-- section title end -->
        </div>
        <!-- home end -->
        <?php endif; ?>
        <!-- vertical lines start -->
        <div class="vertical-lines-wrapper">
            <div class="vertical-lines"></div>
        </div>
        <!-- vertical lines end -->
        <?php if ( '' !== $settings['description'] and $settings['show_description'] ) : ?>
        <!-- section start -->
        <div class="bg-light">
            <div class="container container-fix">
                <div class="extra-margin-all post-spacing">
                    <!-- divider start -->
                    <div class="inner-divider"></div>
                    <!-- divider end -->
                    <!-- row start -->
                    <div class="row">
                        <!-- col start -->
                        <div class="col-lg-12">
                            <div class="post-spacing-3">
                                <!-- section txt start -->
                                <div class="intro">
                                    <?php print wp_kses_post($settings['description']); ?>                           
                                </div>
                                <!-- section txt end -->
                                <!-- divider start -->
                                <div class="inner-divider-half"></div>
                                <!-- divider end -->
                                <!-- section txt start -->
                                <div class="testimonials-signature">
                                    <?php print wp_kses_post($settings['author']); ?>
                                </div>
                                <!-- section txt end -->
                            </div>
                        </div>
                        <!-- col end -->
                    </div>
                    <!-- row end -->
                </div>
            </div>
        </div>
        <!-- section end -->
        <?php endif; ?>
	<?php
	}

}